@@ -410,7 +410,7 @@ class MockElastAlerter(object):
         args.es_debug_trace = False
 
         conf = load_conf(args, defaults, overwrites)
-        rule_yaml = conf['rules_loader'].get_yaml(args.file)
+        rule_yaml = conf['rules_loader'].load_yaml(args.file)
         conf['rules_loader'].load_options(rule_yaml, conf, args.file)
 
         if args.json:
